/**
 * Biopet is built on top of GATK Queue for building bioinformatic
 * pipelines. It is mainly intended to support LUMC SHARK cluster which is running
 * SGE. But other types of HPC that are supported by GATK Queue (such as PBS)
 * should also be able to execute Biopet tools and pipelines.
 *
 * Copyright 2014 Sequencing Analysis Support Core - Leiden University Medical Center
 *
 * Contact us at: sasc@lumc.nl
 *
 * A dual licensing mode is applied. The source code within this project that are
 * not part of GATK Queue is freely available for non-commercial use under an AGPL
 * license; For commercial users or users who do not want to follow the AGPL
 * license, please contact us to obtain a separate license.
 */
package nl.lumc.sasc.biopet.extensions.gatk

import java.io.File

import nl.lumc.sasc.biopet.utils.config.Configurable
import org.broadinstitute.gatk.utils.commandline.{ Input, Output }

class CatVariants(val root: Configurable) extends Gatk {
  val analysisType = "CatVariants"

  @Input(doc = "", required = true)
  var inputFiles: List[File] = Nil

  @Output(doc = "", required = true)
  var outputFile: File = null

  override def cmdLine = super.cmdLine +
    (for (file <- inputFiles) yield {
      required("-V", file)
    }).mkString +
    required("-o", outputFile)

}

object CatVariants {
  def apply(root: Configurable, input: List[File], output: File): CatVariants = {
    val cv = new CatVariants(root)
    cv.inputFiles = input
    cv.outputFile = output
    cv
  }
}